pub struct DataRange {
pub x: Option<(f64, f64)>,
pub y: Option<(f64, f64)>,
pub y2: Option<(f64, f64)>,
}Expand description
The full data range of a plot, mirroring silx _PlotDataRange
(PlotWidget.getDataRange). Each member is the (min, max) data bounds for
that axis, or None when no data is associated with the axis.
Fields
x: Option<(f64, f64)>X-axis data bounds, or None when no item drives the X axis.
y: Option<(f64, f64)>Left Y-axis data bounds.
y2: Option<(f64, f64)>Right (y2) Y-axis data bounds.