pub type Scene3dId = u64;Expand description
Scene identity key (mirrors crate::core::plot::PlotId); lets several
independent 3D scenes coexist in one egui app without sharing GPU state.
pub type Scene3dId = u64;Scene identity key (mirrors crate::core::plot::PlotId); lets several
independent 3D scenes coexist in one egui app without sharing GPU state.