viewpoint_menu

Function viewpoint_menu 

pub fn viewpoint_menu(
    ui: &mut Ui,
    scene: &mut SceneWidget,
) -> Option<CameraFace>
Draw a viewpoint drop-down menu button (port of silx tools.ViewpointTools.ViewpointToolButton): a View button whose menu sets one of the seven predefined viewpoints on scene. Returns the chosen CameraFace when a preset is selected this frame, otherwise None.